@@ -20,6 +20,7 @@
 //!
 //! This is enabled by default.
 //!
+//! [`tracing`]: https://crates.io/crates/tracing
 //! [Discord's documentation]: https://discord.com/developers/docs/topics/rate-limits
 
 #![deny(
@@ -32,8 +33,7 @@
     rust_2018_idioms,
     rustdoc::broken_intra_doc_links,
     unsafe_code,
-    unused,
-    warnings
+    unused
 )]
 #![allow(
     clippy::module_name_repetitions,
